@@ -1,49 +1,36 @@
-#========================================================================
-#
 # LaTeX::Driver
 #
 # DESCRIPTION
 #   Driver module that encapsulates the details of formatting a LaTeX document
 #
-# AUTHOR
-#   Andrew Ford <a.ford@ford-mason.co.uk>  (current maintainer)
-#
-# COPYRIGHT
-#   Copyright (C) 2009 Ford & Mason Ltd.   All Rights Reserved.
-#   Copyright (C) 2006-2007 Andrew Ford.   All Rights Reserved.
-#   Portions Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-#
-#   This module is free software; you can redistribute it and/or
-#   modify it under the same terms as Perl itself.
-#
-# HISTORY
-#   * Added test for reruns required by longtable environments changing (AF, 2009-01-19)
-#
-#   * Extracted from the Template::Latex module (AF, 2007-09-10)
-#
-#   $Id: Driver.pm 76 2009-01-19 13:39:01Z andrew $
-#========================================================================
 
 package LaTeX::Driver;
 
 use strict;
 use warnings;
 
-use base 'Class::Accessor';
-use Cwd;                        # from PathTools
-use English;                    # standard Perl class
+use 5.008005;
+
+use parent 'Class::Accessor';
+use Cwd;                                # from PathTools
+use English qw( -no_match_vars );       # standard Perl class
 use Exception::Class ( 'LaTeX::Driver::Exception' );
-use File::Copy;                 # standard Perl class
-use File::Compare;              # standard Perl class
-use File::Path;                 # standard Perl class
+use File::Copy;                         # standard Perl class
+use File::Compare;                      # standard Perl class
+use File::Path;                         # standard Perl class
 use File::Slurp;
-use File::Spec;                 # from PathTools
-use IO::File;                   # from IO
+use File::Spec;                         # from PathTools
+use IO::File;                           # from IO
+use Readonly;
+use File::pushd;                        # temporary cwd changes
+use Capture::Tiny qw(capture);
 
-our $VERSION = 0.08;
+Readonly our $DEFAULT_MAXRUNS => 10;
 
-__PACKAGE__->mk_accessors( qw( basename basedir basepath options tmpdir
-                               source output tmpdir format
+our $VERSION = "1.1.1";
+
+__PACKAGE__->mk_accessors( qw( basename basedir basepath options
+                               source output tmpdir format timeout stderr
                                formatter preprocessors postprocessors _program_path
                                maxruns extraruns stats texinputs_path
                                undefined_citations undefined_references
@@ -55,13 +42,12 @@ our $DEBUGPREFIX;
 
 # LaTeX executable paths set at installation time by the Makefile.PL
 
-eval { require LaTeX::Driver::Paths };
-
-our @PROGRAM_NAMES = qw(latex pdflatex bibtex makeindex dvips dvipdfm ps2pdf pdf2ps);
-our %program_path;
-
-map { $program_path{$_} = $LaTeX::Driver::Paths::program_path{$_} || "/usr/bin/$_" } @PROGRAM_NAMES;
+our @PROCESSORS      = qw(xelatex lualatex pdflatex latex);
+our @AUXILLARY_PROGS = qw(bibtex makeindex);
+our @POSTPROCESSORS  = qw(dvips dvipdfm ps2pdf pdf2ps);
+our @PROGRAM_NAMES   = (@PROCESSORS, @AUXILLARY_PROGS, @POSTPROCESSORS);
 
+our %program_path = map { ( $_ => $_ ) } @PROGRAM_NAMES;
 
 our @LOGFILE_EXTS = qw( log blg ilg );
 our @TMPFILE_EXTS = qw( aux log lot toc bbl ind idx cit cbk ibk );
@@ -78,10 +64,16 @@ our %FORMATTERS  = (
     dvi        => [ 'latex' ],
     ps         => [ 'latex', 'dvips' ],
     postscript => [ 'latex', 'dvips' ],
-    pdf        => [ 'pdflatex' ],
-    'pdf(dvi)' => [ 'latex', 'dvipdfm' ],
-    'pdf(ps)'  => [ 'latex', 'dvips', 'ps2pdf' ],
-    'ps(pdf)'  => [ 'pdflatex', 'pdf2ps' ],
+    pdf        => [ 'xelatex' ],
+    'pdf(pdflatex)' => [ 'pdflatex' ],
+    'pdf(xelatex)'  => [ 'xelatex' ],
+    'pdf(lualatex)'  => [ 'lualatex' ],
+    'pdf(dvi)'      => [ 'latex', 'dvipdfm' ],
+    'pdf(ps)'       => [ 'latex', 'dvips', 'ps2pdf' ],
+    'ps(pdf)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(pdflatex)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(xelatex)'       => [ 'xelatex', 'pdf2ps' ],
+    'ps(lualatex)'       => [ 'lualatex', 'pdf2ps' ],
 );
 
 
@@ -97,7 +89,7 @@ sub new {
     my $class = shift;
     my $options = ref $_[0] ? shift : { @_ };
     my ($volume, $basedir, $basename, $basepath, $orig_ext, $cleanup);
-    my ($formatter, @postprocessors, %path);
+    my ($formatter, @postprocessors);
 
     $DEBUG       = $options->{DEBUG} || 0;
     $DEBUGPREFIX = $options->{DEBUGPREFIX} if exists $options->{DEBUGPREFIX};
@@ -105,7 +97,7 @@ sub new {
     # Sanity check first - check we're running on a supported OS
 
     $class->throw("not available on $OSNAME")
-        if $OSNAME =~ /^(MacOS|os2|VMS)$/i;
+        if $OSNAME =~ m/ ^ ( MacOS | os2 | VMS ) $ /ix;
 
 
     # Examine the options - we need at least a source to work with and
@@ -120,10 +112,10 @@ sub new {
             if ref $source ne 'SCALAR';
     }
     else {
-        $source =~ s/(\.tex)$//;
+        $source =~ s/ ( [.] tex ) $ //x;
         $orig_ext = $1;
         $class->throw("source file ${source}.tex does not exist")
-            unless -f $source or -f $source . ".tex";
+            unless -f $source or -f "${source}.tex";
     }
 
 
@@ -132,13 +124,15 @@ sub new {
     # specified it is taken from that, or the default is take.
 
     my $output = $options->{output};
-    my $format = lc($options->{format});
+    my $format;
+    $format = lc($options->{format})
+        if $options->{format};
 
-    if ($output and !ref $output) {
+    if ($output and (!ref $output)) {
         my ($volume, $dir, $file) = File::Spec->splitpath($output);
         $class->throw("output directory $dir does not exist")
             unless $dir and -d $dir;
-        if (!$format and $file =~ /\.(\w+)$/) {
+        if ((!$format) and ($file =~ / [.] ( \w+ ) $ /x)) {
             $format = lc($1);
         }
     }
@@ -167,9 +161,9 @@ sub new {
     my $tmpdir = $options->{tmpdir};
     if ($tmpdir or ref $source) {
         $basedir = $class->_setup_tmpdir($tmpdir);
-        $cleanup = 'rmdir' if (!defined($tmpdir) or ($tmpdir eq "1"));
+        $cleanup = 'rmdir' if ((!defined($tmpdir)) or ($tmpdir eq "1"));
         if (ref $source) {
-            $basename = $DEFAULT_DOCNAME; 
+            $basename = $DEFAULT_DOCNAME;
             $basepath = File::Spec->catfile($basedir, $basename);
             write_file($basepath . ".tex", $source)
                 or $class->throw("cannot create temporary latex file");
@@ -177,9 +171,9 @@ sub new {
         else {
             ($basename = $source) =~ s{.*/}{};
             $basepath = File::Spec->catfile($basedir, $basename);
-            copy("$source$orig_ext", $basepath . ".tex")
+            copy("$source$orig_ext", "${basepath}.tex")
                 or $class->throw("cannot copy $source$orig_ext to temporary directory");
-            $output  ||= $source . '.' . $format;
+            $output  ||= "${source}.$format";
         }
     }
 
@@ -216,6 +210,10 @@ sub new {
     my $texinputs_path = $options->{TEXINPUTS} || $options->{texinputs} || [];
     $texinputs_path = [ split(/:/, $texinputs_path) ] unless ref $texinputs_path;
 
+    # see http://tex.stackexchange.com/questions/149714/149865#149865
+
+    my $texinputs_sep = $OSNAME eq "MSWin32" ? ';' : ':';
+
 
     # construct and return the object
 
@@ -226,15 +224,17 @@ sub new {
                                  output         => $output,
                                  cleanup        => $cleanup || '',
                                  options        => $options,
-                                 maxruns        => $options->{maxruns}   || 10,
+                                 maxruns        => $options->{maxruns}   || $DEFAULT_MAXRUNS,
                                  extraruns      => $options->{extraruns} ||  0,
+                                 timeout        => $options->{timeout},
+                                 capture_stderr => $options->{capture_stderr} || 0,
                                  formatter      => $formatter,
                                  _program_path  => $path,
-                                 texinputs_path => join(':', ('.', @$texinputs_path, '')),
+                                 texinputs_path => join($texinputs_sep, ('.', @{$texinputs_path}, '')),
                                  preprocessors  => [],
                                  postprocessors => \@postprocessors,
                                  stats          => { runs => {} } } );
-    
+
 }
 
 
@@ -251,7 +251,7 @@ sub run {
 
     # Check that the file exists
 
-    $self->throw(sprintf("file %s.tex does not exist", $self->basepath))
+    $self->throw(sprintf('file %s.tex does not exist', $self->basepath))
         unless -f $self->basepath . '.tex';
 
 
@@ -268,20 +268,14 @@ sub run {
   RUN:
     foreach my $run (1 .. $maxruns) {
 
-        if ($self->need_to_run_latex) {
+        if ($self->need_to_run_latex or $extraruns-- > 0) {
             $self->run_latex;
         }
-        else {
-            if ($self->need_to_run_bibtex) {
-                $self->run_bibtex;
-            }
-            elsif ($self->need_to_run_makeindex) {
-                $self->run_makeindex;
-            }
-            else {
-                last RUN unless $extraruns-- > 0;
-            }
-            $run--;
+        elsif ($self->need_to_run_bibtex) {
+            $self->run_bibtex;
+        }
+        elsif ($self->need_to_run_makeindex) {
+            $self->run_makeindex;
         }
     }
 
@@ -307,8 +301,8 @@ sub run {
 
     # Return any output
 
-    $self->copy_to_output if $self->output;
-        ;
+    $self->copy_to_output
+        if $self->output;
 
     return 1;
 }
@@ -326,6 +320,7 @@ sub DESTROY {
     debug('DESTROY called') if $DEBUG;
 
     $self->cleanup();
+    return;
 }
 
 
@@ -340,7 +335,7 @@ sub run_latex {
 
     my $basename = $self->basename;
     my $exitcode = $self->run_command($self->formatter =>
-                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{$basename}");
+                                      "\\nonstopmode\\def\\TTLATEX{1}\\input{./$basename}");
 
     # If an error occurred attempt to extract the interesting lines
     # from the log file.  Even without errors the log file may contain
@@ -350,50 +345,50 @@ sub run_latex {
     my $errors = "";
     my $logfile = $self->basepath . ".log";
 
-    if (my $fh = new IO::File $logfile, "r") {
+    if (my $fh = IO::File->new($logfile, "r")) {
         $self->reset_latex_required;
         my $matched = 0;
-        while ( <$fh> ) {
-            debug($_) if $DEBUG >= 9;
+        while ( my $line = <$fh> ) {
+            debug($line) if $DEBUG >= 9;
             # TeX errors start with a "!" at the start of the
             # line, and followed several lines later by a line
             # designator of the form "l.nnn" where nnn is the line
             # number.  We make sure we pick up every /^!/ line,
             # and the first /^l.\d/ line after each /^!/ line.
-            if ( /^(!.*)/ ) {
+            if ( $line =~ /^(!.*)/ ) {
                 $errors .= $1 . "\n";
                 $matched = 1;
             }
-            elsif ( $matched && /^(l\.\d.*)/ ) {
+            elsif ( $matched && ($line =~ /^(l\.\d.*)/) ) {
                 $errors .= $1 . "\n";
                 $matched = 0;
             }
-            elsif ( /^Output written on (.*) \((\d+) pages, (\d+) bytes\)./ ) {
+            elsif ( $line =~ /^Output written on (.*) \((\d+) pages, (\d+) bytes\)./ ) {
                 my ($ofile, $pages, $bytes) = ($1, $2, $3);
                 $self->{stats}{pages} = $pages;
                 $self->{stats}{bytes} = $bytes;
             }
-            elsif ( /^LaTeX Warning: Reference .*? on page \d+ undefined/ ) {
+            elsif ( $line =~ /^LaTeX Warning: Reference .*? on page \d+ undefined/ ) {
                 $self->undefined_references(1);
             }
-            elsif ( /^LaTeX Warning: Citation .* on page \d+ undefined/ ) {
+            elsif ( $line =~ /^LaTeX Warning: Citation .* on page \d+ undefined/ ) {
                 debug('undefined citations detected') if $DEBUG;
                 $self->undefined_citations(1);
             }
-            elsif ( /LaTeX Warning: There were undefined references./i ) {
+            elsif ( $line =~ /LaTeX Warning: There were undefined references./i ) {
                 debug('undefined reference detected') if $DEBUG;
                 $self->undefined_references(1)
                     unless $self->undefined_citations;
             }
-            elsif ( /No file $basename\.(toc|lof|lot)/i ) {
+            elsif ( $line =~ /No file $basename\.(toc|lof|lot)/i ) {
                 debug("missing $1 file") if $DEBUG;
                 $self->undefined_references(1);
             }
-            elsif ( /^LaTeX Warning: Label\(s\) may have changed./i ) {
+            elsif ( $line =~ /^LaTeX Warning: Label\(s\) may have changed./i ) {
                 debug('labels have changed') if $DEBUG;
                 $self->labels_changed(1);
             }
-            elsif ( /^Package longtable Warning: Table widths have changed\. Rerun LaTeX\./i) {
+            elsif ( $line =~ /^Package longtable Warning: Table widths have changed[.] Rerun LaTeX[.]/i) {
                 debug('table widths changed') if $DEBUG;
                 $self->rerun_required(1);
             }
@@ -401,7 +396,7 @@ sub run_latex {
             # A number of packages emit 'rerun' warnings (revtex4,
             # pdfmark, etc); this regexp catches most of those.
 
-            elsif ( /Rerun to get (.*) right/i) {
+            elsif ( $line =~ /Rerun to get (.*) right/i) {
                 debug("$1 changed") if $DEBUG;
                 $self->rerun_required(1);
             }
@@ -495,16 +490,16 @@ sub need_to_run_bibtex {
     my $self = shift;
 
     if ($self->undefined_citations) {
-        my $auxfile = $self->basepath . ".aux";
-        my $citfile = $self->basepath . ".cit";
-        my $cbkfile = $self->basepath . ".cbk";
+        my $auxfile = $self->basepath . '.aux';
+        my $citfile = $self->basepath . '.cit';
+        my $cbkfile = $self->basepath . '.cbk';
 
-        my $auxfh = new IO::File $auxfile, "r" or return;
-        my $citfh = new IO::File $citfile, "w"
+        my $auxfh = IO::File->new($auxfile, 'r') or return;
+        my $citfh = IO::File->new($citfile, 'w')
             or $self->throw("failed to open $citfile for output: $!");
 
-        while ( <$auxfh> ) {
-            print($citfh $_) if /^\\citation/;
+        while ( my $line = <$auxfh> ) {
+            print($citfh $line) if $line =~ /^\\citation/;
         }
         undef $auxfh;
         undef $citfh;
@@ -534,12 +529,12 @@ sub run_makeindex {
     my $basename = $self->basename;
     my @args;
     if (my $stylename = $self->options->{indexstyle}) {
-        push @args, "-s", $stylename;
+        push @args, '-s', $stylename;
     }
     if (my $index_options = $self->options->{indexoptions}) {
         push @args, $index_options;
     }
-    my $exitcode = $self->run_command(makeindex => join(" ", (@args, $basename)));
+    my $exitcode = $self->run_command(makeindex => [@args, $basename]);
 
     # TODO: extract meaningful error message from .ilg file
 
@@ -589,7 +584,7 @@ sub run_dvips {
 
     my $basename = $self->basename;
 
-    my $exitstatus = $self->run_command(dvips => "$basename -o");
+    my $exitstatus = $self->run_command(dvips => [$basename, '-o']);
 
     $self->throw("dvips $basename failed ($exitstatus)")
         if $exitstatus;
@@ -608,7 +603,7 @@ sub run_ps2pdf {
 
     my $basename = $self->basename;
 
-    my $exitstatus = $self->run_command(ps2pdf => sprintf("%s.ps %s.pdf", $basename, $basename));
+    my $exitstatus = $self->run_command(ps2pdf => ["$basename.ps", "$basename.pdf"]);
 
     $self->throw("ps2pdf $basename failed ($exitstatus)")
         if $exitstatus;
@@ -627,7 +622,7 @@ sub run_pdf2ps {
 
     my $basename = $self->basename;
 
-    my $exitstatus = $self->run_command(pdf2ps => sprintf("%s.pdf %s.ps", $basename, $basename));
+    my $exitstatus = $self->run_command(pdf2ps => ["$basename.pdf", "$basename.ps"]);
 
     $self->throw("pdf2ps $basename failed ($exitstatus)")
         if $exitstatus;
@@ -645,6 +640,9 @@ sub run_pdf2ps {
 sub run_command {
     my ($self, $progname, $args, $envvars) = @_;
 
+    $args = [ $args ]
+        unless ref $args;
+
     # get the full path to the executable for this output format
     my $program = $self->program_path($progname)
         || $self->throw("$progname cannot be found, please specify its location");
@@ -659,28 +657,44 @@ sub run_command {
     # Set up localized environment variables in preparation for running the command
     # Note that the localized hash slice assignment of %ENV ensures that
     # the localization is done at the same block level as the system().
-    # Even doing something like  local($ENV{$_}) = $val for @{$envvars} 
+    # Even doing something like  local($ENV{$_}) = $val for @{$envvars}
     # puts the localization in a deeper level block so the previous value
     # is restored before the system() call is made.
 
     $envvars ||= "TEXINPUTS";
     $envvars = [ $envvars ] unless ref $envvars;
     local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
+    $self->stats->{runs}{$progname}++;
+    debug("running '$program $args'") if $DEBUG;
+    my $cwd = pushd($dir);
 
     # Format the command appropriately for our O/S
+
+    my $exit_status;
+    my $exit_error;
+    my ($stdout, $stderr);
     if ($OSNAME eq 'MSWin32') {
-        $cmd = "cmd /c \"cd $dir && $program $args\"";
+        $args = join(' ', @$args);
+        $cmd  = "\"$program\" $args";
+        ($stdout, $stderr) = capture {
+            $exit_status = system($cmd);
+            $exit_error = "$!";
+        };
     }
     else {
         $args = "'$args'" if $args =~ / \\ /mx;
-        $cmd  = "cd $dir; $program $args 1>$null 2>$null 0<$null";
+        ($stdout, $stderr) = capture {
+            $exit_status = system($program, @$args);
+            $exit_error = "$!";
+        };
     }
+    if ($exit_status == -1) {
+        $self->throw( "Failure to start $program: $exit_error" );
+    }
+    $self->{stderr} .= $stderr
+        if $self->{capture_stderr};
 
-    $self->stats->{runs}{$progname}++;
-    debug("running '$program $args'") if $DEBUG;
-
-    my $exitstatus = system($cmd);
-    return $exitstatus;
+    return $exit_status;
 }
 
 
@@ -700,7 +714,7 @@ sub copy_to_output {
         $$output = read_file($file);
     }
     else {
-        # see if we can rename the generate file to the desired output 
+        # see if we can rename the generated file to the desired output
         # file - this may fail, e.g. across filesystem boundaries (and
         # it's quite common for /tmp to be a separate filesystem
 
@@ -722,7 +736,7 @@ sub copy_to_output {
 #------------------------------------------------------------------------
 # _setup_tmpdir($dirname)
 #
-# create a temporary directory 
+# create a temporary directory
 #------------------------------------------------------------------------
 
 sub _setup_tmpdir {
@@ -732,16 +746,16 @@ sub _setup_tmpdir {
 
     if ($dirname and ($dirname ne 1)) {
         $dirname = File::Spec->catdir($tmp, $dirname);
-        eval { mkpath($dirname, 0, 0700) } unless -d $dirname;
+        eval { mkpath($dirname, 0, oct(700)) } unless -d $dirname;
     }
     else {
         my $n = 0;
-        do { 
+        do {
             $dirname = File::Spec->catdir($tmp, "$DEFAULT_TMPDIR$$" . '_' . $n++);
         } while (-e $dirname);
-        eval { mkpath($dirname, 0, 0700) };
+        eval { mkpath($dirname, 0, oct(700)) };
     }
-    $class->throw("cannot create temporary directory: $@") 
+    $class->throw("cannot create temporary directory: $@")
         if $@;
 
     debug(sprintf("setting up temporary directory '%s'\n", $dirname)) if $DEBUG;
@@ -762,7 +776,7 @@ sub cleanup {
     my $cleanup = $self->{cleanup};
     debug('cleanup called') if $DEBUG;
     if ($cleanup eq 'rmdir') {
-        if (!defined($what) or ($what ne 'none')) {
+        if ((!defined $what) or ($what ne 'none')) {
             debug('cleanup removing directory tree ' . $self->basedir) if $DEBUG;
             rmtree($self->basedir);
         }
@@ -774,7 +788,7 @@ sub cleanup {
 #------------------------------------------------------------------------
 # $self->program_path($progname, $optional_value)
 #
-# 
+#
 #------------------------------------------------------------------------
 
 sub program_path {
@@ -794,13 +808,15 @@ sub program_path {
 #------------------------------------------------------------------------
 
 sub throw {
-    my $self = shift;
-    LaTeX::Driver::Exception->throw( error => join('', @_) );
+    my ($self, @args) = @_;
+    LaTeX::Driver::Exception->throw( error => join('', @args) );
+    return; # not needed - but satisfies perlcritic
 }
 
 sub debug {
-    print STDERR $DEBUGPREFIX || "[latex] ", @_;
-    print STDERR "\n" unless $_[-1] =~ / \n $ /mx;
+    my (@args) = @_;
+    print STDERR $DEBUGPREFIX || "[latex] ", @args;
+    print STDERR "\n" unless @args and ($args[-1] =~ / \n $ /mx);
     return;
 }
 
@@ -815,7 +831,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-This document describes version 0.08 of C<LaTeX::Driver>.
+1.1.1
 
 =head1 SYNOPSIS
 
@@ -844,6 +860,12 @@ result of the processing up to a dozen or more intermediate files are
 created.  These can be removed with the C<cleanup> method.
 
 
+=head1 SOURCE
+
+Source code can be found at L<https://github.com/fordmason/LaTeX-Driver>
+
+Feel free to fork and add your stuff!
+
 =head1 SUBROUTINES/METHODS
 
 =over 4
@@ -883,6 +905,38 @@ C<"pdf(dvi)"> (generates PDF via dvi, using C<dvipdfm>).  If not
 specified then the format is determined from the name of the output
 document if specified, or defaults to PDF.
 
+The following list of formats is supported
+
+=over
+
+=item * dvi
+
+=item * ps
+
+=item * postscript
+
+=item * pdf
+
+=item * pdf(pdflatex)
+
+=item * pdf(xelatex)
+
+=item * pdf(lualatex)
+
+=item * pdf(dvi)
+
+=item * pdf(ps)
+
+=item * ps(pdf)
+
+=item * ps(pdflatex)
+
+=item * ps(xelatex)
+
+=item * ps(lualatex)
+
+=back
+
 =item C<tmpdir>
 
 Specifies whether the formatting should be done in a temporary
@@ -908,6 +962,11 @@ The maximum number of runs of the formatter program (defaults to 10).
 
 The number of additional runs of the formatter program after the document has stabilized.
 
+=item C<timeout>
+
+Specifies a timeout in seconds within which any commands spawned
+should finish.  
+
 =item C<cleanup>
 
 Specifies whether temporary files and directories should be
@@ -932,7 +991,7 @@ for full details.
 
 =item C<texinputs>
 
-Specifies one or more directories to be searched for LaTeX files.  
+Specifies one or more directories to be searched for LaTeX files.
 
 =item C<DEBUG>
 
@@ -967,11 +1026,15 @@ The constructor method returns a driver object.
 
 Format the document.
 
+=item C<stderr>
+
+Holds the error output from subcommands, if the C<-capture_stderr>
+option was passed to C<new()>.
 
 =item C<stats()>
 
 Returns a reference to a hash containing stats about the processing
-tht was performed, containing the following items:
+that was performed, containing the following items:
 
 =over 4
 
@@ -1090,7 +1153,7 @@ explicitly tested for).
 
 =item no source specified
 
-The C<source> paramater should be specified as the name of a LaTeX
+The C<source> parameter should be specified as the name of a LaTeX
 source file or it should be a reference to a scalar variable holding
 the LaTeX source document.
 
@@ -1196,6 +1259,11 @@ location.
 C<LaTeX::Driver> depends on latex and friends being installed.
 
 
+=head1 INCOMPATIBILITIES
+
+None known.
+
+
 =head1 BUGS AND LIMITATIONS
 
 This is beta software - there are bound to be bugs and misfeatures.
@@ -1226,7 +1294,7 @@ paths.
 
 =item *
 
-Investigate pre- and post-processors and other auxilliary programs.
+Investigate pre- and post-processors and other auxiliary programs.
 
 =back
 
@@ -1290,7 +1358,7 @@ widespread yet.
 
 BiBTeX generates a bibliography for a LaTeX document.  It reads the
 top-level auxiliary file (C<.aux>) output during the running of latex and
-creates a bibliograpy file (C<.bbl>) that will be incorporated into the
+creates a bibliography file (C<.bbl>) that will be incorporated into the
 document on subsequent runs of latex.  It looks up the entries
 specified by \cite and \nocite commands in the bibliographic database
 files (.bib) specified by the \bibliography commands.  The entries are
@@ -1336,14 +1404,15 @@ the web2c TeX distribution, TeX live, tetex, TeX on Windows, etc.
 
 =head1 AUTHOR
 
-Andrew Ford E<lt>a.ford@ford-mason.co.ukE<gt>
-
+   Chris Travers <chris.travers@gmail.com>  (current maintainer)
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2009 Ford & Mason Ltd.  All Rights Reserved.
-
-Copyright (C) 2007 Andrew Ford.  All Rights Reserved.
+   Copyright (C) 2020  Erik Huelsmann.
+   Copyright (C) 2014  Chris Travers.
+   Copyright (C) 2009-2013 Ford & Mason Ltd.
+   Copyright (C) 2006-2007 Andrew Ford.
+   Portions Copyright (C) 1996-2006 Andy Wardley.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
